<?php

namespace Drupal\drd_pi;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface for defining Account entities.
 */
interface DrdPiAccountInterface extends ConfigEntityInterface {

  /**
   * Configuration name for accounts of this type.
   *
   * @return string
   *   Config name.
   */
  public static function getConfigName();

  /**
   * Name of the platform.
   *
   * @return string
   *   Platform name.
   */
  public function getPlatformName();

  /**
   * Synchronise this account with DRD.
   *
   * @return $this
   */
  public function sync();

  /**
   * Retrieve a list of hosts from the platform.
   *
   * @return DrdPiHost[]
   *   List of hosts.
   */
  public function getPlatformHosts();

  /**
   * Retrieve a list of cores for the host from the platform.
   *
   * @param DrdPiHost $host
   *   The host for which to retrieve cores.
   *
   * @return DrdPiCore[]
   *   List of cores.
   */
  public function getPlatformCores(DrdPiHost $host);

  /**
   * Retrieve a list of domains for host from the platform.
   *
   * @param DrdPiCore $core
   *   The core for which to retrieve domains.
   *
   * @return DrdPiDomain[]
   *   List of domains.
   */
  public function getPlatformDomains(DrdPiCore $core);

  /**
   * Execute Drush command on platform.
   *
   * @param DrdPiDomain $domain
   *   The domain entity for which to execute the Drush command.
   * @param string $drushcmd
   *   The Drush command.
   *
   * @return bool
   *   Whether the command executed successfully or not.
   */
  public function drush(DrdPiDomain $domain, $drushcmd);

}
